# Example illustrating application of filters.
# In this example we apply a shrink filter to a sphere source.
# This also illustrates use of lookup tables for scalar coloring.
# Pipeline:
# SphereSource --> Shrink --> (Representation, RenderView)

from paraview import servermanager

# We create a server connection only if one isn't already present.
if not servermanager.ActiveConnection:
  servermanager.Connect()

# First create a data source -- in this example we are simply rendering a sphere
# so we create a sphere source.

# Default parameter values can be specified as arguments to the constructor.
sphere = servermanager.sources.SphereSource(Radius=10.5)
# Parameter values can later be accessed/changed as follows:
sphere.PhiResolution = 10
sphere.ThetaResolution = 10

# Now create a view to show the data in.
view = servermanager.CreateRenderView()

# A representation maps the data produced by a source/filter to the view.
# So to show the data in a view, we need to create a representation for it.
reprSphere = servermanager.CreateRepresentation(sphere, view)

# Set solid color for the sphere to be red.
reprSphere.DiffuseColor = [0.5, 0.5, 0.2]
reprSphere.AmbientColor = [0.5, 0.5, 0.2]

# Set representation style to wireframe so that it does not overlap with the
# result of the shrink filter
reprSphere.Representation = "Wireframe"

# To hide reprSphere totally, simple un-comment the following line:
# reprSphere.Visibility = 0

# Now create the shrink filter and connect the sphere as its input.
shrink = servermanager.filters.ShrinkFilter(Input=sphere)

# Change paramater on the filter.
shrink.ShrinkFactor = 0.8

# Create a representation for the shrink to be able to see the result in the
# view.
reprShrink = servermanager.CreateRepresentation(shrink, view)

# Now set up the scalar coloring. We want to color by the 1st component of the
# "Normals" array.

# Choose the attribute type. Acceptable values are "POINT_DATA" (or 0),
# "CELL_DATA" (or 1) 
reprShrink.ColorAttributeType = "POINT_DATA"

# Select the name of the array to color with.
reprShrink.ColorArrayName = "Normals"

# Now create a lookup-table to map the scalar values to colors.
lut = servermanager.rendering.PVLookupTable()
lut.RGBPoints  = [0.0, 0.0, 0.0, 1.0,
                  1.0, 1.0, 0.0, 0.0]
# Since we want to color by the 1st component of the normals vector
lut.VectorComponent = 1
lut.VectorMode = "Component" ;# Another acceptable value is "Magnitude" to
                              # color by vector magnitude.

# Assign the lut to the representation
reprShrink.LookupTable = lut

# Reset the camera position so that all data is visible
view.ResetCamera()

# Render
view.StillRender()

raw_input("Hit 'Enter' to continue: ")
